@@ -10,21 +10,22 @@ import shutil
 import subprocess
 import time
 import urllib
+from typing import Any, TypeVar, Union
 
 
-def openWindowsFolder(folder):
+def openWindowsFolder(folder: str):
     os.system(f"start explorer {folder}")
 
 
-def getPath(basePath, *parList):
+def getPath(basePath: str, *parList: str) -> str:
     return os.path.abspath(os.path.join(basePath, *parList))
 
 
-def getDesktopPath(*parList):
+def getDesktopPath(*parList: Any):
     return getPath(os.path.expanduser("~"), "Desktop", *parList)
 
 
-def writeFile(file, data, encoding='utf8', newline='\n'):
+def writeFile(file: str, data: str, encoding: str = 'utf8', newline: str = '\n'):
     makeFolder(os.path.dirname(file))
     with open(file, 'w', encoding=encoding, newline=newline) as f:
         f.write(data)
@@ -33,7 +34,7 @@ def writeFile(file, data, encoding='utf8', newline='\n'):
     return file
 
 
-def writeBinFile(file, data):
+def writeBinFile(file: str, data: bytes):
     makeFolder(os.path.dirname(file))
     with open(file, 'wb') as f:
         f.write(data)
@@ -42,44 +43,44 @@ def writeBinFile(file, data):
     return file
 
 
-def readFile(file, encoding='utf8', newline='\n'):
+def readFile(file: str, encoding: str = 'utf8', newline: str = '\n'):
     with open(file, 'r', encoding=encoding, newline=newline) as f:
         data = f.read()
         f.close()
     return data
 
 
-def readBinFile(file):
+def readBinFile(file: str):
     with open(file, 'rb') as f:
         data = f.read()
         f.close()
     return data
 
 
-def jsonDumps(value):
+def jsonDumps(value: Any):
     return json.dumps(value, ensure_ascii=False, sort_keys=True, separators=(',', ':'))
 
 
-def remove(fileOrFolder):
+def remove(fileOrFolder: str):
     if os.path.isfile(fileOrFolder):
         os.remove(fileOrFolder)
     elif os.path.isdir(fileOrFolder):
         shutil.rmtree(fileOrFolder)
 
 
-def makeFolder(folder):
+def makeFolder(folder: str):
     if not os.path.exists(folder):
         os.makedirs(folder)
 
 
-def clearFolder(*folderAry):
+def clearFolder(*folderAry: str):
     for folder in folderAry:
         if os.path.isdir(folder):
             for target in getFileAndFolderList(folder):
                 remove(target)
 
 
-def copy(fromFileOrFolder, toFileOrFolder):
+def copy(fromFileOrFolder: str, toFileOrFolder: str):
     if os.path.isfile(fromFileOrFolder):
         fromFile = fromFileOrFolder
         toFile = toFileOrFolder
@@ -92,7 +93,7 @@ def copy(fromFileOrFolder, toFileOrFolder):
         shutil.copytree(fromFolder, toFolder)
 
 
-def getParentFolder(fileOrFolder, level=1):
+def getParentFolder(fileOrFolder: str, level: int = 1):
     result = fileOrFolder
     while level > 0:
         level -= 1
@@ -100,17 +101,17 @@ def getParentFolder(fileOrFolder, level=1):
     return result
 
 
-def getFileExtName(file):
+def getFileExtName(file: str):
     return file[file.rfind('.') + 1:].lower()
 
 
-def getFileBaseName(file):
+def getFileBaseName(file: str):
     fileName = os.path.basename(file)
     return fileName[:fileName.rfind(".")]
 
 
-def getFileList(folder):
-    ary = []
+def getFileList(folder: str):
+    ary: list[str] = []
     for targetName in os.listdir(folder):
         target = os.path.join(folder, targetName)
         if os.path.isfile(target):
@@ -118,8 +119,8 @@ def getFileList(folder):
     return ary
 
 
-def getFolderList(folder):
-    ary = []
+def getFolderList(folder: str):
+    ary: list[str] = []
     for targetName in os.listdir(folder):
         target = os.path.join(folder, targetName)
         if os.path.isdir(target):
@@ -127,16 +128,16 @@ def getFolderList(folder):
     return ary
 
 
-def getFileAndFolderList(folder):
-    ary = []
+def getFileAndFolderList(folder: str):
+    ary: list[str] = []
     for targetName in os.listdir(folder):
         target = os.path.join(folder, targetName)
         ary.append(target)
     return ary
 
 
-def getAllFileList(folder):
-    ary = []
+def getAllFileList(folder: str):
+    ary: list[str] = []
     for targetName in getFileAndFolderList(folder):
         target = os.path.join(folder, targetName)
         if os.path.isfile(target):
@@ -146,8 +147,8 @@ def getAllFileList(folder):
     return ary
 
 
-def getAllFolderList(folder):
-    ary = []
+def getAllFolderList(folder: str):
+    ary: list[str] = []
     for targetName in getFileAndFolderList(folder):
         target = os.path.join(folder, targetName)
         if os.path.isdir(target):
@@ -156,8 +157,8 @@ def getAllFolderList(folder):
     return ary
 
 
-def getAllFileAndFolderList(folder):
-    ary = []
+def getAllFileAndFolderList(folder: str):
+    ary: list[str] = []
     for targetName in getFileAndFolderList(folder):
         target = os.path.join(folder, targetName)
         if os.path.isfile(target):
@@ -168,28 +169,28 @@ def getAllFileAndFolderList(folder):
     return ary
 
 
-def getFileMD5(file):
+def getFileMD5(file: str):
     data = readBinFile(file)
     return hashlib.md5(data).hexdigest()
 
 
-def getFileCRC(file):
+def getFileCRC(file: str):
     return getDataCRC(readBinFile(file))
 
 
-def getContentCRC(content):
+def getContentCRC(content: str):
     return getDataCRC(content.encode())
 
 
-def getDataCRC(data):
+def getDataCRC(data: bytes):
     return hex(binascii.crc32(data))[2:].zfill(8)
 
 
-def getClassFullName(classItem):
+def getClassFullName(classItem: Any):
     return getattr(classItem, '__module__') + '.' + getattr(classItem, '__name__')
 
 
-def makeTempWorkspace(clearOneDayBefore=True):
+def makeTempWorkspace(clearOneDayBefore: bool = True):
     baseWorkspaceFoler = getPath(os.path.expanduser("~"), "beniutils.workspace")
     makeFolder(baseWorkspaceFoler)
     nowTime = int(time.time() * 10000000)
@@ -207,7 +208,7 @@ def makeTempWorkspace(clearOneDayBefore=True):
     raise Exception("创建tempWorkspace目录失败")
 
 
-def execute(*pars, showCmd=True, showOutput=False, ignoreError=False):
+def execute(*pars: str, showCmd: bool = True, showOutput: bool = False, ignoreError: bool = False):
     from . import log
     cmd = ' '.join(pars)
     if showCmd:
@@ -221,7 +222,7 @@ def execute(*pars, showCmd=True, showOutput=False, ignoreError=False):
     outBytes, errBytes = p.communicate()
     p.kill()
     if showOutput:
-        from .bytes import decode
+        from .byte import decode
         outStr = decode(outBytes).replace("\r\n", "\n")
         errStr = decode(errBytes).replace("\r\n", "\n")
         if outStr:
@@ -233,8 +234,8 @@ def execute(*pars, showCmd=True, showOutput=False, ignoreError=False):
     return p.returncode, outBytes, errBytes
 
 
-def executeWinScp(winscpExe, keyFile, server, commandAry, showCmd=True):
-    logFile = getPath(pathlib.Path.home(), "executeWinScp.log")
+def executeWinScp(winscpExe: str, keyFile: str, server: str, commandAry: list[str], showCmd: bool = True):
+    logFile = getPath(str(pathlib.Path.home()), "executeWinScp.log")
     remove(logFile)
     ary = [
         'option batch abort',
@@ -251,8 +252,8 @@ def executeWinScp(winscpExe, keyFile, server, commandAry, showCmd=True):
     return execute(cmd, showCmd=showCmd)
 
 
-def executeTry(*parList, output=None, error=None):
-    _code, outputBytes, errorBytes = execute(*parList, showCmd=False, ignoreError=True)
+def executeTry(*parList: str, output: str = "", error: str = ""):
+    _, outputBytes, errorBytes = execute(*parList, showCmd=False, ignoreError=True)
     if type(output) == str:
         output = output.encode()
     if output and output not in outputBytes:
@@ -263,7 +264,7 @@ def executeTry(*parList, output=None, error=None):
         raise Exception(f"命令执行失败：{' '.join(parList)}")
 
 
-def syncFolder(fromFolder, toFolder):
+def syncFolder(fromFolder: str, toFolder: str):
     # 删除多余目录
     toSubFolderList = sorted(getAllFolderList(toFolder), reverse=True)
     for toSubFolder in toSubFolderList:
@@ -299,21 +300,18 @@ def syncFolder(fromFolder, toFolder):
 _DEFAULT_FMT = '%Y-%m-%d %H:%M:%S'
 
 
-def timestampByStr(value, fmt=None):
-    fmt = fmt or _DEFAULT_FMT
+def timestampByStr(value: str, fmt: str = _DEFAULT_FMT):
     return int(time.mktime(time.strptime(value, fmt)))
 
 
-def strByTimestamp(timestamp=None, fmt=None):
-    timestamp = timestamp or time.time()
-    fmt = fmt or _DEFAULT_FMT
+def strByTimestamp(timestamp: float = time.time(), fmt: str = _DEFAULT_FMT):
     ary = time.localtime(timestamp)
     return time.strftime(fmt, ary)
 
 
-def hold(msg=None, showInput=True, *exitValueList):
+def hold(msg: str = "", showInput: bool = True, *exitValueList: str):
     msg = msg or "测试暂停，输入exit可以退出"
-    exitValueList = exitValueList or ["exit"]
+    exitValueList = exitValueList or ("exit",)
     inputFunc = showInput and input or getpass.getpass
     while True:
         inputValue = inputFunc(f"{msg}：")
@@ -339,7 +337,7 @@ _opener = urllib.request.build_opener(_cookieProc)
 urllib.request.install_opener(_opener)
 
 
-def _getHeaderByDefault(headers):
+def _getHeaderByDefault(headers: dict[str, str]):
     result = dict(_defaultHeader)
     if headers:
         for key, value in headers.items():
@@ -347,7 +345,7 @@ def _getHeaderByDefault(headers):
     return result
 
 
-def httpGet(url, headers=None, timeout=30, retry=3):
+def httpGet(url: str, headers: dict[str, str] = {}, timeout: int = 30, retry: int = 3):
     method = 'GET'
     headers = _getHeaderByDefault(headers)
     result = None
@@ -369,7 +367,7 @@ def httpGet(url, headers=None, timeout=30, retry=3):
     return result, response
 
 
-def httpPost(url, data=None, headers=None, timeout=30, retry=3):
+def httpPost(url: str, data=None, headers: dict[str, str] = {}, timeout: int = 30, retry: int = 3):
     method = 'POST'
     headers = _getHeaderByDefault(headers)
     postData = data
@@ -391,7 +389,11 @@ def httpPost(url, data=None, headers=None, timeout=30, retry=3):
     return result, response
 
 
-def toFloat(value, default):
+IntFloatStr = Union[int, float, str]
+IntFloat = Union[int, float]
+
+
+def toFloat(value: IntFloatStr, default: float):
     result = default
     try:
         result = float(value)
@@ -400,7 +402,7 @@ def toFloat(value, default):
     return result
 
 
-def toInt(value, default):
+def toInt(value: IntFloatStr, default: int):
     result = default
     try:
         result = int(value)
@@ -409,7 +411,7 @@ def toInt(value, default):
     return result
 
 
-def getLimitedValue(value, minValue, maxValue):
+def getLimitedValue(value: IntFloat, minValue: IntFloat, maxValue: IntFloat):
     value = min(value, maxValue)
     value = max(value, minValue)
     return value
@@ -418,12 +420,12 @@ def getLimitedValue(value, minValue, maxValue):
 _xPar = "0123456789abcdefghijklmnopqrstuvwxyz"
 
 
-def intToX(value):
+def intToX(value: int) -> str:
     n = len(_xPar)
     return ((value == 0) and "0") or (intToX(value // n).lstrip("0") + _xPar[value % n])
 
 
-def xToInt(value):
+def xToInt(value: str):
     return int(value, len(_xPar))
 
 
