@@ -1,5 +1,6 @@
 import logging
 import os
+from typing import Any
 
 from . import makeFolder
 
@@ -78,7 +79,7 @@ def debug(msg, *args, **kwargs):
     logging.getLogger(_loggerName).debug(msg, *args, **kwargs)
 
 
-def info(msg, *args, **kwargs):
+def info(msg: str, *args: Any, **kwargs: Any):
     logging.getLogger(_loggerName).info(msg, *args, **kwargs)
 
 
