@@ -23,9 +23,6 @@ def initTask(exeWorkspace, devWorkspace, devTaskList):
     else:
         _workspacePath = getPath(exeWorkspace)
         _runTaskFile(sys.argv[-1])
-    if not _isDev():
-        while True:
-            time.sleep(1)
 
 
 def getPathByWorkspace(*parList) -> str:
@@ -103,8 +100,9 @@ def _runTaskFile(file):
 # [[moduleName, parDict], ...]
 def _runTaskList(taskList):
     startTime = datetime.datetime.now()
-    lockFile = _checkLockFile()
+    lockFile = None
     try:
+        lockFile = _checkLockFile()
         logFolder = getPath(_workspacePath, "log")
         makeFolder(logFolder)
         for logFile in sorted(getAllFileList(logFolder), reverse=True)[100:]:
@@ -152,4 +150,9 @@ def _runTaskList(taskList):
         info(f"用时：{passTime}")
 
         resetPrintColor()
-        remove(lockFile)
+        if lockFile:
+            remove(lockFile)
+
+        if not _isDev():
+            while True:
+                time.sleep(1)
